moody API documentation

# Package `moody`

Expand source code

    # Token = namedtuple('Token', ['address', 'name', 'code_hash'], defaults=(None,) * 3)
    import sys
    from dataclasses import dataclass

    if sys.version_info < (3, 5):
        raise EnvironmentError("Python 3.5 or above is required")

    # __version__ = pkg_resources.get_distribution("moodyeth").version

    # __all__ = [
    #    '__version__',
    # ]

    @dataclass
    class Token:
        address: str = None
        name: str = None
        code_hash: str = None
        token_contract: str = None

    @dataclass
    class Config:
        network_name: str
        rpc_url: str
        chain_id: int
        symbol: str
        block_explorer: str
        bridge: str = "",
        gas: int = 500000,
        gasPrice: int = 1000000000

    @dataclass
    class Key:
        private_key: str
        wallet_address: str
        token: str
        precision: int
        network: str

## Sub-modules

`moody.bridge`
`moody.buildercompile`
`moody.bulk`
`moody.bussen`
`moody.conf`
`moody.erc20`
`moody.libeb`
`moody.m`
`moody.paths`

  Base wrapper class for accessing ethereum smart contracts.

## Classes

`class Config (network_name: str, rpc_url: str, chain_id: int, symbol: str, block_explorer: str, bridge: str = ('',), gas: int = (500000,), gasPrice: int = 1000000000)`

  Config(network_name: str, rpc_url: str, chain_id: int, symbol: str, block_explorer: str, bridge: str = ('',), gas: int = (500000,), gasPrice: int = 1000000000)

  Expand source code

      class Config:
          network_name: str
          rpc_url: str
          chain_id: int
          symbol: str
          block_explorer: str
          bridge: str = "",
          gas: int = 500000,
          gasPrice: int = 1000000000

  ### Class variables

  `var block_explorer : str`
  `var bridge : str`
  `var chain_id : int`
  `var gas : int`
  `var gasPrice : int`
  `var network_name : str`
  `var rpc_url : str`
  `var symbol : str`
`class Key (private_key: str, wallet_address: str, token: str, precision: int, network: str)`

  Key(private_key: str, wallet_address: str, token: str, precision: int, network: str)

  Expand source code

      class Key:
          private_key: str
          wallet_address: str
          token: str
          precision: int
          network: str

  ### Class variables

  `var network : str`
  `var precision : int`
  `var private_key : str`
  `var token : str`
  `var wallet_address : str`
`class Token (address: str = None, name: str = None, code_hash: str = None, token_contract: str = None)`

  Token(address: str = None, name: str = None, code_hash: str = None, token_contract: str = None)

  Expand source code

      class Token:
          address: str = None
          name: str = None
          code_hash: str = None
          token_contract: str = None

  ### Class variables

  `var address : str`
  `var code_hash : str`
  `var name : str`
  `var token_contract : str`